from .dane import DaneBenchmark  # noqa
from .ddt_pos import DdtPosBenchmark  # noqa
from .ddt_dep import DdtDepBenchmark  # noqa
from .angry_tweets import AngryTweetsBenchmark  # noqa
from .twitter_sent import TwitterSentBenchmark  # noqa
from .europarl import EuroparlBenchmark  # noqa
from .lcc import LccBenchmark  # noqa
from .dkhate import DkHateBenchmark  # noqa
from .norec import NorecBenchmark  # noqa
from .nordial import NorDialBenchmark  # noqa
from .norne_nb import NorneNBBenchmark  # noqa
from .norne_nn import NorneNNBenchmark  # noqa
from .ndt_nb_pos import NdtNBPosBenchmark  # noqa
from .ndt_nn_pos import NdtNNPosBenchmark  # noqa
from .ndt_nb_dep import NdtNBDepBenchmark  # noqa
from .ndt_nn_dep import NdtNNDepBenchmark  # noqa
from .dalaj import DalajBenchmark  # noqa
from .absabank_imm import AbsabankImmBenchmark # noqa
from .sdt_pos import SdtPosBenchmark  # noqa
from .sdt_dep import SdtDepBenchmark  # noqa
from .suc3 import Suc3Benchmark  # noqa
from .idt_pos import IdtPosBenchmark  # noqa
from .idt_dep import IdtDepBenchmark  # noqa
from .fdt_pos import FdtPosBenchmark  # noqa
from .fdt_dep import FdtDepBenchmark  # noqa
from .mim_gold_ner import MimGoldNerBenchmark  # noqa
from .wikiann_fo import WikiannFoBenchmark  # noqa
from .norec_is import NorecISBenchmark  # noqa
from .norec_fo import NorecFOBenchmark  # noqa
